"""cascade deletes

Revision ID: d51edf5acbee
Revises: 78c4d3384497
Create Date: 2018-06-20 15:20:41.994830

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "d51edf5acbee"
down_revision = "78c4d3384497"
branch_labels = None
depends_on = None


def upgrade():
    #     "alerts_feed_id_fkey" FOREIGN KEY (feed_id, feed_version) REFERENCES feeds(id, version)
    op.drop_constraint("alerts_feed_id_fkey", "alerts", type_="foreignkey")
    op.create_foreign_key(
        "alerts_feed_id_fkey",
        "alerts",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
        ondelete="CASCADE",
    )

    #     "feed_augmentation_hashes_feed_id_fkey" FOREIGN KEY (feed_id, feed_version) REFERENCES feeds(id, version)
    op.drop_constraint(
        "feed_augmentation_hashes_feed_id_fkey",
        "feed_augmentation_hashes",
        type_="foreignkey",
    )
    op.create_foreign_key(
        "feed_augmentation_hashes_feed_id_fkey",
        "feed_augmentation_hashes",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
        ondelete="CASCADE",
    )

    #     "ignore_feed_id_fkey" FOREIGN KEY (feed_id, feed_version) REFERENCES feeds(id, version)
    op.drop_constraint("ignore_feed_id_fkey", "ignore", type_="foreignkey")
    op.create_foreign_key(
        "ignore_feed_id_fkey",
        "ignore",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
        ondelete="CASCADE",
    )

    #     "iocs_report_id_fkey" FOREIGN KEY (report_id, feed_id, feed_version) REFERENCES reports(id, feed_id, feed_version)
    op.drop_constraint("iocs_report_id_fkey", "iocs", type_="foreignkey")
    op.create_foreign_key(
        "iocs_report_id_fkey",
        "iocs",
        "reports",
        ["report_id", "feed_id", "feed_version"],
        ["id", "feed_id", "feed_version"],
        ondelete="CASCADE",
    )

    #     "iocs_v2_report_id_fkey" FOREIGN KEY (report_id, feed_id, feed_version) REFERENCES reports(id, feed_id, feed_version)
    op.drop_constraint("iocs_v2_report_id_fkey", "iocs_v2", type_="foreignkey")
    op.create_foreign_key(
        "iocs_v2_report_id_fkey",
        "iocs_v2",
        "reports",
        ["report_id", "feed_id", "feed_version"],
        ["id", "feed_id", "feed_version"],
        ondelete="CASCADE",
    )

    #     "report_score_overrides_feed_id_fkey" FOREIGN KEY (feed_id, feed_version) REFERENCES feeds(id, version)
    op.drop_constraint(
        "report_score_overrides_feed_id_fkey",
        "report_score_overrides",
        type_="foreignkey",
    )
    op.create_foreign_key(
        "report_score_overrides_feed_id_fkey",
        "report_score_overrides",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
        ondelete="CASCADE",
    )

    #     "reports_feed_id_fkey" FOREIGN KEY (feed_id, feed_version) REFERENCES feeds(id, version)
    op.drop_constraint("reports_feed_id_fkey", "reports", type_="foreignkey")
    op.create_foreign_key(
        "reports_feed_id_fkey",
        "reports",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
        ondelete="CASCADE",
    )

    #     "subscriptions_feed_id_version_access_owner_fkey" FOREIGN KEY (feed_id, feed_version, feed_access, feed_owner) REFERENCES feeds(id, version, access, owner) ON UPDATE CASCADE
    op.drop_constraint(
        "subscriptions_feed_id_version_access_owner_fkey",
        "subscriptions",
        type_="foreignkey",
    )
    op.create_foreign_key(
        "subscriptions_feed_id_version_access_owner_fkey",
        "subscriptions",
        "feeds",
        ["feed_id", "feed_version", "feed_access", "feed_owner"],
        ["id", "version", "access", "owner"],
        onupdate="CASCADE",
        ondelete="CASCADE",
    )


def downgrade():  # pragma: no cover
    op.drop_constraint("alerts_feed_id_fkey", "alerts", type_="foreignkey")
    op.create_foreign_key(
        "alerts_feed_id_fkey",
        "alerts",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
    )

    op.drop_constraint(
        "feed_augmentation_hashes_feed_id_fkey",
        "feed_augmentation_hashes",
        type_="foreignkey",
    )
    op.create_foreign_key(
        "feed_augmentation_hashes_feed_id_fkey",
        "feed_augmentation_hashes",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
    )

    op.drop_constraint("ignore_feed_id_fkey", "ignore", type_="foreignkey")
    op.create_foreign_key(
        "ignore_feed_id_fkey",
        "ignore",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
    )

    op.drop_constraint("iocs_report_id_fkey", "iocs", type_="foreignkey")
    op.create_foreign_key(
        "iocs_report_id_fkey",
        "iocs",
        "reports",
        ["report_id", "feed_id", "feed_version"],
        ["id", "feed_id", "feed_version"],
    )

    op.drop_constraint("iocs_v2_report_id_fkey", "iocs_v2", type_="foreignkey")
    op.create_foreign_key(
        "iocs_v2_report_id_fkey",
        "iocs_v2",
        "reports",
        ["report_id", "feed_id", "feed_version"],
        ["id", "feed_id", "feed_version"],
    )

    op.drop_constraint(
        "report_score_overrides_feed_id_fkey",
        "report_score_overrides",
        type_="foreignkey",
    )
    op.create_foreign_key(
        "report_score_overrides_feed_id_fkey",
        "report_score_overrides",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
    )

    op.drop_constraint("reports_feed_id_fkey", "reports", type_="foreignkey")
    op.create_foreign_key(
        "reports_feed_id_fkey",
        "reports",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
    )

    op.drop_constraint(
        "subscriptions_feed_id_version_access_owner_fkey",
        "subscriptions",
        type_="foreignkey",
    )
    op.create_foreign_key(
        "subscriptions_feed_id_version_access_owner_fkey",
        "subscriptions",
        "feeds",
        ["feed_id", "feed_version", "feed_access", "feed_owner"],
        ["id", "version", "access", "owner"],
        onupdate="CASCADE",
    )
