"""remove feed version

Revision ID: ee31f8ccf334
Revises: 3fe41b8275a2
Create Date: 2018-07-02 14:50:30.327203

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "ee31f8ccf334"
down_revision = "3fe41b8275a2"
branch_labels = None
depends_on = None


def upgrade():
    op.execute("ALTER TABLE feeds DROP COLUMN version CASCADE")
    op.create_primary_key("feeds_pkey", "feeds", ["id"])
    op.create_unique_constraint(
        "uc_id_owner_access", "feeds", ["id", "owner", "access"]
    )

    op.create_foreign_key(
        None, "reports", "feeds", ["feed_id"], ["id"], ondelete="CASCADE"
    )
    op.execute("ALTER TABLE reports DROP COLUMN feed_version CASCADE")
    op.create_primary_key("reports_pkey", "reports", ["id", "feed_id"])

    op.create_foreign_key(
        None, "alerts", "feeds", ["feed_id"], ["id"], ondelete="CASCADE"
    )
    op.drop_column("alerts", "feed_version")
    op.create_primary_key("alerts_pkey", "alerts", ["org_id", "feed_id"])

    op.create_foreign_key(
        None,
        "feed_augmentation_hashes",
        "feeds",
        ["feed_id"],
        ["id"],
        ondelete="CASCADE",
    )
    op.drop_column("feed_augmentation_hashes", "feed_version")
    op.create_primary_key(
        "feed_augmentation_hashes_pkey",
        "feed_augmentation_hashes",
        ["org_id", "feed_id"],
    )

    op.create_foreign_key(
        None, "ignore", "feeds", ["feed_id"], ["id"], ondelete="CASCADE"
    )
    op.drop_column("ignore", "feed_version")
    op.create_primary_key(
        "ignore_pkey", "ignore", ["org_id", "feed_id", "report_id", "ioc_id"]
    )

    op.create_foreign_key(
        "iocs_report_id_fkey",
        "iocs",
        "reports",
        ["report_id", "feed_id"],
        ["id", "feed_id"],
        ondelete="CASCADE",
    )
    op.drop_column("iocs", "feed_version")
    op.create_primary_key("iocs_pkey", "iocs", ["report_id", "feed_id"])

    op.create_foreign_key(
        "iocs_v2_report_id_fkey",
        "iocs_v2",
        "reports",
        ["report_id", "feed_id"],
        ["id", "feed_id"],
        ondelete="CASCADE",
    )
    op.drop_column("iocs_v2", "feed_version")
    op.create_primary_key("iocs_v2_pkey", "iocs_v2", ["id", "report_id", "feed_id"])

    op.create_foreign_key(
        None, "report_score_overrides", "feeds", ["feed_id"], ["id"], ondelete="CASCADE"
    )
    op.drop_column("report_score_overrides", "feed_version")
    op.create_primary_key(
        "report_score_overrides_pkey",
        "report_score_overrides",
        ["org_id", "feed_id", "report_id"],
    )

    op.create_foreign_key(
        "subscriptions_feed_id_fkey",
        "subscriptions",
        "feeds",
        ["feed_id", "feed_access", "feed_owner"],
        ["id", "access", "owner"],
        onupdate="CASCADE",
        ondelete="CASCADE",
    )
    op.drop_column("subscriptions", "feed_version")
    op.create_primary_key("subscriptions_pkey", "subscriptions", ["org_id", "feed_id"])


def downgrade():  # pragma: no cover
    op.add_column(
        "feeds", sa.Column("version", sa.VARCHAR(), autoincrement=False, nullable=False)
    )
    op.drop_constraint(None, "feeds", type_="primarykey")
    op.create_primary_key("feeds_pkey", "feeds", ["id", "version"])

    op.add_column(
        "subscriptions",
        sa.Column("feed_version", sa.VARCHAR(), autoincrement=False, nullable=False),
    )
    op.drop_constraint(None, "subscriptions", type_="foreignkey")
    op.create_foreign_key(
        "subscriptions_feed_id_version_access_owner_fkey",
        "subscriptions",
        "feeds",
        ["feed_id", "feed_version", "feed_access", "feed_owner"],
        ["id", "version", "access", "owner"],
        onupdate="CASCADE",
        ondelete="CASCADE",
    )
    op.add_column(
        "reports",
        sa.Column("feed_version", sa.VARCHAR(), autoincrement=False, nullable=False),
    )
    op.drop_constraint(None, "reports", type_="foreignkey")
    op.create_foreign_key(
        "reports_feed_id_fkey",
        "reports",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
        ondelete="CASCADE",
    )
    op.add_column(
        "report_score_overrides",
        sa.Column("feed_version", sa.VARCHAR(), autoincrement=False, nullable=False),
    )
    op.drop_constraint(None, "report_score_overrides", type_="foreignkey")
    op.create_foreign_key(
        "report_score_overrides_feed_id_fkey",
        "report_score_overrides",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
        ondelete="CASCADE",
    )
    op.add_column(
        "iocs_v2",
        sa.Column("feed_version", sa.VARCHAR(), autoincrement=False, nullable=False),
    )
    op.drop_constraint(None, "iocs_v2", type_="foreignkey")
    op.create_foreign_key(
        "iocs_v2_report_id_fkey",
        "iocs_v2",
        "reports",
        ["report_id", "feed_id", "feed_version"],
        ["id", "feed_id", "feed_version"],
        ondelete="CASCADE",
    )
    op.add_column(
        "iocs",
        sa.Column("feed_version", sa.VARCHAR(), autoincrement=False, nullable=False),
    )
    op.drop_constraint(None, "iocs", type_="foreignkey")
    op.create_foreign_key(
        "iocs_report_id_fkey",
        "iocs",
        "reports",
        ["report_id", "feed_id", "feed_version"],
        ["id", "feed_id", "feed_version"],
        ondelete="CASCADE",
    )
    op.add_column(
        "ignore",
        sa.Column("feed_version", sa.VARCHAR(), autoincrement=False, nullable=False),
    )
    op.drop_constraint(None, "ignore", type_="foreignkey")
    op.create_foreign_key(
        "ignore_feed_id_fkey",
        "ignore",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
        ondelete="CASCADE",
    )
    op.create_unique_constraint(
        "uc_id_version_owner_access", "feeds", ["id", "version", "owner", "access"]
    )
    op.drop_constraint("uc_id_owner_access", "feeds", type_="unique")
    op.add_column(
        "feed_augmentation_hashes",
        sa.Column("feed_version", sa.VARCHAR(), autoincrement=False, nullable=False),
    )
    op.drop_constraint(None, "feed_augmentation_hashes", type_="foreignkey")
    op.create_foreign_key(
        "feed_augmentation_hashes_feed_id_fkey",
        "feed_augmentation_hashes",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
        ondelete="CASCADE",
    )
    op.add_column(
        "alerts",
        sa.Column("feed_version", sa.VARCHAR(), autoincrement=False, nullable=False),
    )
    op.drop_constraint(None, "alerts", type_="foreignkey")
    op.create_foreign_key(
        "alerts_feed_id_fkey",
        "alerts",
        "feeds",
        ["feed_id", "feed_version"],
        ["id", "version"],
        ondelete="CASCADE",
    )
