from configparser import ExtendedInterpolation, RawConfigParser
import os


class Config(RawConfigParser):
    _DEFAULT_INTERPOLATION = ExtendedInterpolation()

    def get(self, section, option, **kwargs):
        # Return environment variable for section/option if exists
        env_var = self._get_env_var(f"{section}.{option}")
        if env_var in os.environ:
            return os.environ[env_var]

        return super(Config, self).get(section, option, **kwargs)

    @staticmethod
    def _get_env_var(section_option):
        return section_option.replace(".", "_").upper()

    @classmethod
    def create(cls):
        cfg = cls(allow_no_value=True)
        cfg.optionxform = str  # Use case-sensitive strings for option names
        cfg.read(
            os.path.join(os.path.dirname(os.path.abspath(__file__)), "../feedmgr.ini")
        )

        return cfg
