import datetime
import logging

from aio_pyformance.registry import MetricsRegistry

from feed_manager.engine.org_watchlist_state_updater import OrgWatchlistStateUpdater
from feed_manager.utils.db import ReadWriteDbPool

from feed_manager.engine.watchlist_engine import WatchlistEngine
from pscr_common.utils import get_utcnow_with_tzinfo

from feed_manager.utils.tasks.background_task import BackgroundTask
from feed_manager.utils.config import Config

_logger = logging.getLogger(__name__)


class OrgWatchlistQueueBuildTask(BackgroundTask):
    def __init__(
        self,
        config: Config,
        db_pool: ReadWriteDbPool,
        metrics: MetricsRegistry,
        watchlist_engine: WatchlistEngine,
    ):
        super(OrgWatchlistQueueBuildTask, self).__init__(
            "org_watchlist_queue_build",
            loop_sec=config.getint(
                "watchlist", "requeue_check_minutes", fallback=60 * 24
            )
            * 60,
            sleep_first=True,
            execute_once=False,
        )
        self.db_pool = db_pool
        self.metrics = metrics
        self.watchlist_engine = watchlist_engine
        self.config = config

    async def execute(self, app):
        threshold = get_utcnow_with_tzinfo() - datetime.timedelta(
            minutes=self.config.getint(
                "watchlist", "requeue_check_minutes", fallback=60 * 24
            )
        )

        state_updater = OrgWatchlistStateUpdater(self.config)

        org_ids = await self.watchlist_engine.get_stale_watchlist_orgs(threshold)
        self.metrics.gauge("watchlists.build.stale").set_value(len(org_ids))

        for org_id in org_ids:
            state_updater.set_dirty_for_org_id(org_id)

        async with self.db_pool.rw_transaction() as conn:
            await state_updater.execute(conn)
