import logging

from aiohttp import web

from feed_manager.engine.feed_engine import FeedEngine
from feed_manager.web.route_helpers import make_response_json
from pscr_common.web.auth import AuthRouteTableDef

_logger = logging.getLogger(__name__)


def build_route_table(engine: FeedEngine) -> AuthRouteTableDef:
    routes = AuthRouteTableDef()

    @routes.get("/v1/orgs/{org_key}/feeds/{feed_id}", allow_head=False)
    async def get_feed(request: web.Request):
        # look out for log messages and eventually remove custom internal endpoint
        _logger.info("Hit get_feed")

        feed_id = request.match_info["feed_id"]
        org_key = request.match_info["org_key"]

        feed = await engine.get_feed(org_key, feed_id)

        return make_response_json(FeedEngine.remove_empty_feed_scope(feed))

    @routes.post("/v1/orgs/{org_id}/publish")
    async def publish_org_reports(request: web.Request):
        # look out for log messages and eventually remove custom internal endpoint
        _logger.info("Hit publish_org_reports")

        org_id = request.match_info["org_id"]

        results = await engine.publish_org_reports(org_id)

        return make_response_json({"results": results})

    @routes.post("/v1/orgs/{org_id}/feeds/{feed_id}/publish")
    async def publish_org_reports_for_feed(request: web.Request):
        # look out for log messages and eventually remove custom internal endpoint
        _logger.info("Hit publish_org_reports_for_feed")

        org_id = request.match_info["org_id"]
        feed_id = request.match_info["feed_id"]

        num_reports = await engine.publish_org_reports_for_feed(org_id, feed_id)

        return make_response_json(
            {"results": [{"feed_id": feed_id, "num_reports": num_reports}]}
        )

    return routes
